package
module
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Mar 14, 2026
License: BSD-2-Clause
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
My personal errors package for Go.
Docs
Documentation
¶
Package errors handles errors my way.
func CheckErr(err error, msg ...interface{})
func (s *Stack) Check(err error, msg ...interface{})
func (s *Stack) Defer(f func())
func (s *Stack) Err(final bool, msg ...interface{})
If final, then process deferred tasks, even when there are no errors
Source Files
¶
Click to show internal directories.
Click to hide internal directories.