package
module
Version:
v0.3.0
Opens a new window with list of versions in this module.
Published: Mar 16, 2026
License: BSD-2-Clause
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
My personal errors package for Go.
Docs
Documentation
¶
Package errors handles errors my way.
func main() {
defer func() {
if errors.Panicked() {
recover()
os.Exit(1)
}
}()
// code
}
func ExitErr(vars ...interface{})
func PanicErr(vars ...interface{})
func WarnErr(vars ...interface{}) error
Source Files
¶
Click to show internal directories.
Click to hide internal directories.